==> common-1.3.1.1-sources.jar: cn/gtmap/gtc/workflow/clients/manage/ProcessInstanceClient.java <==
package cn.gtmap.gtc.workflow.clients.manage;


import cn.gtmap.gtc.workflow.domain.manage.CountersignTaskDto;
import cn.gtmap.gtc.workflow.domain.manage.ProcessInstanceData;
import cn.gtmap.gtc.workflow.domain.manage.ProcessMonthCreateFrequencyDto;
import cn.gtmap.gtc.workflow.domain.manage.TaskData;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/7/11
 * @description 流程实例管理
 *
 */

@FeignClient(name = "${app.services.bpm-manage:bpm-manage}")
@RequestMapping("manage/v1")
public interface ProcessInstanceClient {

    @RequestMapping(value = "/process-instances",method = RequestMethod.GET)
    Object contentpagelist() throws Exception;

    /**
     * 流程实例的启动
     * @param processDefKey             流程定义的唯一标识符
     * @param userName                  用户名
     * @param workDayId                 可选工作日关联Id（如果流程的启动配置没有关联工作日，请填值，不然会抛异常）
     * @param processInstanceName      可选 流程实例的名称
     * @param priority                  可选  流程任务优先级 不填默认一般
     * @param desc                      可选   流程描述
     * @return
     * @throws
     */
    @PostMapping("/process-instances/startUp")
    TaskData startUpProcess(@RequestParam(value = "processDefKey") String processDefKey,
                                   @RequestParam(value = "userName") String userName,
                                   @RequestParam(value = "workDayId",required = false) String workDayId,
                                   @RequestParam(value = "processInstanceName",required = false) String processInstanceName,
                                   @RequestParam(value = "priority",required = false) Integer priority,
                                   @RequestParam(value = "category") String category,
                                   @RequestParam(value = "regionCode",required = false) String regionCode,
                                   @RequestParam(value = "department") String department,
                                   @RequestParam(value = "procDueLimt") Integer procDueLimt,
                                   @RequestParam(value = "isPriority") Integer isPriority,
                                   @RequestParam(value = "desc",required = false) String desc);

    /**
     * 直接启动流程实例
     * @param processDefKey             流程定义的唯一标识符
     * @param userName                  用户名
     * @Param verifyRoleDepartment     (验证角色下方部门)不传不验证,传1开启验证
     * @return
     * @throws Exception
     */
    @PostMapping("/process-instances/direct-startUp")
    TaskData directStartProcessInstance(@RequestParam(value = "processDefKey") String processDefKey,
                                                @RequestParam(value = "userName") String userName,
                                                @RequestParam(value = "processInstanceName",required = false) String processInstanceName,
                                                @RequestParam(value = "regionCode",required = false) String regionCode,
                                                @RequestParam(value = "days", required = false) Integer days);

    /**
     * 设定默认启动角色
     * @param processDefKey             流程定义的唯一标识符
     * @param roleCodes    角色编码， 英文逗号间隔
     * @Param verifyRoleDepartment     (验证角色下方部门)不传不验证,传1开启验证
     * @return
     * @throws Exception
     */
    @PostMapping("/process-instances/role-startUp")
    TaskData directStartByRole(@RequestParam(value = "processDefKey") String processDefKey,
                                      @RequestParam(value = "roleCodes", required = false) String roleCodes,
                                      @RequestParam(value = "regionCode",required = false) String regionCode,
                                      @RequestParam(value = "verifyRoleDepartment",required = false) Integer verifyRoleDepartment,
                                      @RequestParam(value = "processInstanceName",required = false) String processInstanceName);


    /**
     * 使用角色启动流程,可传业务参数
     * @param processDefKey        流程定义Key
     * @param roleCodes            角色编码
     * @param regionCode           行政区编码
     * @param verifyRoleDepartment 验证角色部门
     * @param processInstanceName  流程实例名称
     * @param param {"autoDispatch":true} 开启自动转发
     * @return 返回创建成功的流程
     */
    @PostMapping("/process-instances/role-startUp-param")
    TaskData directStartByRoleAndParam(@RequestParam(value = "processDefKey") String processDefKey,
                                              @RequestParam(value = "roleCodes", required = false) String roleCodes,
                                              @RequestParam(value = "regionCode",required = false) String regionCode,
                                              @RequestParam(value = "verifyRoleDepartment",required = false) Integer verifyRoleDepartment,
                                              @RequestParam(value = "processInstanceName", required = false) String processInstanceName,
                                              @RequestBody(required = false) Map<String,Object> param);

    /**
     * 创建流程变量，设置变量值
     * @param executionId
     * @param variableName
     * @param variableValue
     * @return
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}/{variableValue}/variable",method = RequestMethod.POST)
    void createOrUpdateVariable(@PathVariable("executionId") String executionId,
                                       @PathVariable("variableName") String variableName,
                                       @PathVariable("variableValue") Object variableValue);

    /**
     * 根据executionId和variableName获取variable对象
     * @param executionId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}/variable",method = RequestMethod.GET)
    Object getVariable(@PathVariable("executionId") String executionId,
                              @PathVariable("variableName") String variableName);

    /**
     * 根据executionId获取所有variables对象
     * @param executionId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/variables",method = RequestMethod.GET)
    Map getVariables(@PathVariable("executionId") String executionId);

    /**
     * 删除流程变量
     * @param executionId
     * @param variableName
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}",method = RequestMethod.DELETE)
    void deleteVariable(@PathVariable("executionId") String executionId,
                               @PathVariable("variableName") String variableName);

    /**
     * 流程实例在线编辑
     * @param countersignTaskDtoList
     * @return
     */
    @RequestMapping(value = "/process-instances/proInsEdit",method = RequestMethod.POST)
    @ResponseBody
    int processInstanceEdit(@RequestBody List<CountersignTaskDto> countersignTaskDtoList);

    /**
     * 流程任意节点跳转
     * @param taskId
     * @param targetNodeId
     */
    @RequestMapping(value = "/process-instances/{taskId}/{targetNodeId}/arbitrary-node-jump",method = RequestMethod.POST)
    void arbitraryNodeJump(@PathVariable("taskId") String taskId,
                                  @PathVariable("targetNodeId") String targetNodeId);

    /**
     * 设置优先级
     * @param taskId
     * @param priorityInt
     */
    @Deprecated
    @RequestMapping(value = "/process-instances/{taskId}/{priority}/priority-set",method = RequestMethod.POST)
    String setProcessPriority(@PathVariable("taskId") String taskId,
                              @PathVariable("priority") int priorityInt,
                              @RequestParam(value = "reason",required = false)String reason);

    /**
     * 获取流程实例
     * @param processInstanceId
     * @return
     */
    @RequestMapping(value = "/process-instances/{processInstanceId}/processInstance",method = RequestMethod.GET)
    ProcessInstanceData getProcessInstance(@PathVariable("processInstanceId") String processInstanceId);


    /**
     * 流程实例名称修改
     * @param processInstanceId
     * @param processInstanceName
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/name",method = RequestMethod.GET)
    public void processInstanceEdit(@RequestParam("processInstanceId")String processInstanceId,@RequestParam("processInstanceName") String processInstanceName);

    /**
     * 设置任务优先级
     * @param taskId
     * @param priorityInt
     */
    @RequestMapping(value = "/process-instances/task-priority",method = RequestMethod.POST)
    public void setTaskPriority(@RequestParam("taskId") String taskId,
                                   @RequestParam("priority") int priorityInt,
                                   @RequestParam(value = "reason",required = false)String reason);

    /**
     * 流程实例优先级修改
     *
     * @param procInsId
     * @param priority
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/proc-priority", method = RequestMethod.POST)
    public void setProcPriority(@RequestParam("procInsId") String procInsId, @RequestParam("priority") Integer priority,
                                @RequestParam(value = "reason",required = false)String reason);


    /**
     * 流程启动事件触发接口
     * @param processInsId 流程实例id
     */
    @RequestMapping(value = "/process-instances/exe/AfterCreate",method = RequestMethod.GET)
    void exeAfterCreateForProcessStart(@RequestParam("processInsId") String processInsId);

    /**
     * 查询流程每月限制创建配置以及当月已创建数量
     * @param processDefKey 流程定义key
     * @return 返回配置及本月已创建次数
     */
    @RequestMapping(value = "/process-instances/createProcess/frequency", method = RequestMethod.GET)
    ProcessMonthCreateFrequencyDto countCreateProcessFrequencyForMonth(@RequestParam(name = "processDefKey") String processDefKey);


    /**
     * 修改流程首节点开始时间,及流程开始时间(并重写计算超期时间)
     * @param processInsId 流程实例id
     * @param newTime 新时间 格式:yyyy-MM-dd HH:mm:ss
     * @return 是否修改成功
     */
    @RequestMapping(value = "/process-instances/update/startNodeTime",method = RequestMethod.GET)
    boolean updateStartNodeTime(@RequestParam("processInsId")String processInsId,@RequestParam("newTime") String newTime);



}

==> common-1.3.1.3-sources.jar: cn/gtmap/gtc/workflow/clients/manage/ProcessInstanceClient.java <==
package cn.gtmap.gtc.workflow.clients.manage;


import cn.gtmap.gtc.workflow.domain.manage.CountersignTaskDto;
import cn.gtmap.gtc.workflow.domain.manage.ProcessInstanceData;
import cn.gtmap.gtc.workflow.domain.manage.ProcessMonthCreateFrequencyDto;
import cn.gtmap.gtc.workflow.domain.manage.TaskData;
import org.springframework.cloud.netflix.feign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Map;


/**
 * @author <a href="mailto:yuxinwang@gtmap.cn">yxw</a>
 * @version 1.0, 2018/7/11
 * @description 流程实例管理
 *
 */

@FeignClient(name = "${app.services.bpm-manage:bpm-manage}")
@RequestMapping("manage/v1")
public interface ProcessInstanceClient {

    @RequestMapping(value = "/process-instances",method = RequestMethod.GET)
    Object contentpagelist() throws Exception;

    /**
     * 流程实例的启动
     * @param processDefKey             流程定义的唯一标识符
     * @param userName                  用户名
     * @param workDayId                 可选工作日关联Id（如果流程的启动配置没有关联工作日，请填值，不然会抛异常）
     * @param processInstanceName      可选 流程实例的名称
     * @param priority                  可选  流程任务优先级 不填默认一般
     * @param desc                      可选   流程描述
     * @return
     * @throws
     */
    @PostMapping("/process-instances/startUp")
    TaskData startUpProcess(@RequestParam(value = "processDefKey") String processDefKey,
                                   @RequestParam(value = "userName") String userName,
                                   @RequestParam(value = "workDayId",required = false) String workDayId,
                                   @RequestParam(value = "processInstanceName",required = false) String processInstanceName,
                                   @RequestParam(value = "priority",required = false) Integer priority,
                                   @RequestParam(value = "category") String category,
                                   @RequestParam(value = "regionCode",required = false) String regionCode,
                                   @RequestParam(value = "department") String department,
                                   @RequestParam(value = "procDueLimt") Integer procDueLimt,
                                   @RequestParam(value = "isPriority") Integer isPriority,
                                   @RequestParam(value = "desc",required = false) String desc);

    /**
     * 直接启动流程实例
     * @param processDefKey             流程定义的唯一标识符
     * @param userName                  用户名
     * @Param verifyRoleDepartment     (验证角色下方部门)不传不验证,传1开启验证
     * @return
     * @throws Exception
     */
    @PostMapping("/process-instances/direct-startUp")
    TaskData directStartProcessInstance(@RequestParam(value = "processDefKey") String processDefKey,
                                                @RequestParam(value = "userName") String userName,
                                                @RequestParam(value = "processInstanceName",required = false) String processInstanceName,
                                                @RequestParam(value = "regionCode",required = false) String regionCode,
                                                @RequestParam(value = "days", required = false) Integer days);

    /**
     * 设定默认启动角色
     * @param processDefKey             流程定义的唯一标识符
     * @param roleCodes    角色编码， 英文逗号间隔
     * @Param verifyRoleDepartment     (验证角色下方部门)不传不验证,传1开启验证
     * @return
     * @throws Exception
     */
    @PostMapping("/process-instances/role-startUp")
    TaskData directStartByRole(@RequestParam(value = "processDefKey") String processDefKey,
                                      @RequestParam(value = "roleCodes", required = false) String roleCodes,
                                      @RequestParam(value = "regionCode",required = false) String regionCode,
                                      @RequestParam(value = "verifyRoleDepartment",required = false) Integer verifyRoleDepartment,
                                      @RequestParam(value = "processInstanceName",required = false) String processInstanceName);


    /**
     * 使用角色启动流程,可传业务参数
     * @param processDefKey        流程定义Key
     * @param roleCodes            角色编码
     * @param regionCode           行政区编码
     * @param verifyRoleDepartment 验证角色部门
     * @param processInstanceName  流程实例名称
     * @param param {"autoDispatch":true} 开启自动转发
     * @return 返回创建成功的流程
     */
    @PostMapping("/process-instances/role-startUp-param")
    TaskData directStartByRoleAndParam(@RequestParam(value = "processDefKey") String processDefKey,
                                              @RequestParam(value = "roleCodes", required = false) String roleCodes,
                                              @RequestParam(value = "regionCode",required = false) String regionCode,
                                              @RequestParam(value = "verifyRoleDepartment",required = false) Integer verifyRoleDepartment,
                                              @RequestParam(value = "processInstanceName", required = false) String processInstanceName,
                                              @RequestBody(required = false) Map<String,Object> param);

    /**
     * 创建流程变量，设置变量值
     * @param executionId
     * @param variableName
     * @param variableValue
     * @return
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}/{variableValue}/variable",method = RequestMethod.POST)
    void createOrUpdateVariable(@PathVariable("executionId") String executionId,
                                       @PathVariable("variableName") String variableName,
                                       @PathVariable("variableValue") Object variableValue);

    /**
     * 根据executionId和variableName获取variable对象
     * @param executionId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}/variable",method = RequestMethod.GET)
    Object getVariable(@PathVariable("executionId") String executionId,
                              @PathVariable("variableName") String variableName);

    /**
     * 根据executionId获取所有variables对象
     * @param executionId
     * @return
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/variables",method = RequestMethod.GET)
    Map getVariables(@PathVariable("executionId") String executionId);

    /**
     * 删除流程变量
     * @param executionId
     * @param variableName
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/{executionId}/{variableName}",method = RequestMethod.DELETE)
    void deleteVariable(@PathVariable("executionId") String executionId,
                               @PathVariable("variableName") String variableName);

    /**
     * 流程实例在线编辑
     * @param countersignTaskDtoList
     * @return
     */
    @RequestMapping(value = "/process-instances/proInsEdit",method = RequestMethod.POST)
    @ResponseBody
    int processInstanceEdit(@RequestBody List<CountersignTaskDto> countersignTaskDtoList);

    /**
     * 流程任意节点跳转
     * @param taskId
     * @param targetNodeId
     */
    @RequestMapping(value = "/process-instances/{taskId}/{targetNodeId}/arbitrary-node-jump",method = RequestMethod.POST)
    void arbitraryNodeJump(@PathVariable("taskId") String taskId,
                                  @PathVariable("targetNodeId") String targetNodeId);

    /**
     * 设置优先级
     * @param taskId
     * @param priorityInt
     */
    @Deprecated
    @RequestMapping(value = "/process-instances/{taskId}/{priority}/priority-set",method = RequestMethod.POST)
    String setProcessPriority(@PathVariable("taskId") String taskId,
                              @PathVariable("priority") int priorityInt,
                              @RequestParam(value = "reason",required = false)String reason);

    /**
     * 获取流程实例
     * @param processInstanceId
     * @return
     */
    @RequestMapping(value = "/process-instances/{processInstanceId}/processInstance",method = RequestMethod.GET)
    ProcessInstanceData getProcessInstance(@PathVariable("processInstanceId") String processInstanceId);


    /**
     * 流程实例名称修改
     * @param processInstanceId
     * @param processInstanceName
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/name",method = RequestMethod.GET)
    public void processInstanceEdit(@RequestParam("processInstanceId")String processInstanceId,@RequestParam("processInstanceName") String processInstanceName);

    /**
     * 设置任务优先级
     * @param taskId
     * @param priorityInt
     */
    @RequestMapping(value = "/process-instances/task-priority",method = RequestMethod.POST)
    public void setTaskPriority(@RequestParam("taskId") String taskId,
                                   @RequestParam("priority") int priorityInt,
                                   @RequestParam(value = "reason",required = false)String reason);

    /**
     * 流程实例优先级修改
     *
     * @param procInsId
     * @param priority
     * @throws Exception
     */
    @RequestMapping(value = "/process-instances/proc-priority", method = RequestMethod.POST)
    public void setProcPriority(@RequestParam("procInsId") String procInsId, @RequestParam("priority") Integer priority,
                                @RequestParam(value = "reason",required = false)String reason);


    /**
     * 流程启动事件触发接口
     * @param processInsId 流程实例id
     */
    @RequestMapping(value = "/process-instances/exe/AfterCreate",method = RequestMethod.GET)
    void exeAfterCreateForProcessStart(@RequestParam("processInsId") String processInsId);

    /**
     * 查询流程每月限制创建配置以及当月已创建数量
     * @param processDefKey 流程定义key
     * @return 返回配置及本月已创建次数
     */
    @RequestMapping(value = "/process-instances/createProcess/frequency", method = RequestMethod.GET)
    ProcessMonthCreateFrequencyDto countCreateProcessFrequencyForMonth(@RequestParam(name = "processDefKey") String processDefKey);


    /**
     * 修改流程首节点开始时间,及流程开始时间(并重写计算超期时间)
     * @param processInsId 流程实例id
     * @param newTime 新时间 格式:yyyy-MM-dd HH:mm:ss
     * @return 是否修改成功
     */
    @RequestMapping(value = "/process-instances/update/startNodeTime",method = RequestMethod.GET)
    boolean updateStartNodeTime(@RequestParam("processInsId")String processInsId,@RequestParam("newTime") String newTime);

    /**
     * 修改流程期限
     * @param processInsId
     * @param days
     * @return
     */
    @RequestMapping(value = "/process-instances/update/limit-day",method = RequestMethod.GET)
    public boolean updateProcessLimitTime(@RequestParam("processInsId")String processInsId,
                                          @RequestParam("days") Double days);



}
